@@ -18,8 +18,8 @@ class TestMTLFunctionLog(TestCase):
     def test_constants(self):
         self.assertEqual(Metal.MTLFunctionLogTypeValidation, 0)
 
-    @min_sdk_level("10.16")
-    def test_protocols(self):
+    @min_sdk_level("11.0")
+    def test_protocols11_0(self):
         objc.protocolNamed("MTLLogContainer")
         objc.protocolNamed("MTLFunctionLogDebugLocation")
         objc.protocolNamed("MTLFunctionLog")
